@@ -32,7 +32,8 @@ REGISTER_GROUPS = [
 # Temperature registers
 ###############################################################################
 
-REG_OUTDOOR_TEMPERATURE = "REG_OUTDOOR_TEMPERATURE"
+REG_OUTDOOR_TEMPERATURE = "REG_OUTDOOR_TEMPERATURE" # Not used
+REG_OPER_DATA_OUTDOOR_TEMP_MA_SA = "REG_OPER_DATA_OUTDOOR_TEMP_MA_SA" # Not used
 REG_INDOOR_TEMPERATURE = "REG_INDOOR_TEMPERATURE"
 REG_SUPPLY_LINE = "REG_SUPPLY_LINE"
 REG_HOT_WATER_TEMPERATURE = "REG_HOT_WATER_TEMPERATURE"
@@ -45,6 +46,8 @@ REG_BRINE_IN = "REG_BRINE_IN"
 
 REG_RETURN_LINE = "REG_RETURN_LINE"
 REG_DESIRED_SUPPLY_LINE = "REG_DESIRED_SUPPLY_LINE"
+REG_OPER_DATA_SUPPLY_MA_SA = "REG_OPER_DATA_SUPPLY_MA_SA"
+REG_DESIRED_SUPPLY_LINE_TEMP = "REG_DESIRED_SUPPLY_LINE_TEMP"
 REG_DESIRED_INDOOR_TEMPERATURE = "REG_DESIRED_INDOOR_TEMPERATURE"
 
 ###############################################################################
